@@ -14,12 +14,11 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-
 import taskflow.engines
 from taskflow import exceptions as exc
 from taskflow.patterns import linear_flow
 from taskflow import test
+from taskflow.test import mock
 from taskflow.tests import utils as test_utils
 from taskflow.utils import persistence_utils as p_utils
 
@@ -69,7 +68,7 @@ class FlowFromDetailTestCase(test.TestCase):
         _lb, flow_detail = p_utils.temporary_flow_detail()
         flow_detail.meta = dict(factory=dict(name=name))
 
-        with mock.patch('taskflow.openstack.common.importutils.import_class',
+        with mock.patch('oslo.utils.importutils.import_class',
                         return_value=lambda: 'RESULT') as mock_import:
             result = taskflow.engines.flow_from_detail(flow_detail)
             mock_import.assert_called_onec_with(name)
@@ -80,7 +79,7 @@ class FlowFromDetailTestCase(test.TestCase):
         _lb, flow_detail = p_utils.temporary_flow_detail()
         flow_detail.meta = dict(factory=dict(name=name, args=['foo']))
 
-        with mock.patch('taskflow.openstack.common.importutils.import_class',
+        with mock.patch('oslo.utils.importutils.import_class',
                         return_value=lambda x: 'RESULT %s' % x) as mock_import:
             result = taskflow.engines.flow_from_detail(flow_detail)
             mock_import.assert_called_onec_with(name)
